@@ -10,7 +10,8 @@ test_that("add_censor_mark() works with ggsurvfit()", {
     NA
   )
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("sf1-censor_mark", lst_survfit2_censor_mark[[1]])
   vdiffr::expect_doppelganger("sf2-censor_mark", lst_survfit2_censor_mark[[2]])
   vdiffr::expect_doppelganger("sf3-censor_mark", lst_survfit2_censor_mark[[3]])
@@ -42,7 +43,8 @@ test_that("add_censor_mark() works with ggcuminc()", {
     NA
   )
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("cuminc1-censor_mark", lst_cuminc_censor_mark[[1]])
   vdiffr::expect_doppelganger("cuminc2-censor_mark", lst_cuminc_censor_mark[[2]])
   vdiffr::expect_doppelganger("cuminc3-censor_mark", lst_cuminc_censor_mark[[3]])
@@ -56,7 +58,8 @@ test_that("add_censor_mark() works with ggcuminc()", {
     NA
   )
 
-  skip_on_os("linux")
+  # only check on mac
+  skip_on_ci()
   vdiffr::expect_doppelganger("cuminc1-censor_mark-all-outcomes", lst_cuminc_censor_mark_outcome[[1]])
   vdiffr::expect_doppelganger("cuminc2-censor_mark-all-outcomes", lst_cuminc_censor_mark_outcome[[2]])
   vdiffr::expect_doppelganger("cuminc3-censor_mark-all-outcomes", lst_cuminc_censor_mark_outcome[[3]])
